/*
 * JFreeChartTester.java
 * JUnit based test
 *
 * Created on December 21, 2003, 8:41 PM
 */

package org.jfree.chart.plot;


import org.jfree.chart.plot.util.*;
import org.jfree.data.xy.*;
import org.jfree.chart.*;
import org.jfree.data.category.DefaultCategoryDataset;
import org.jfree.data.category.CategoryDataset;


/**
 *
 * @author Michel Santos
 */
public class JFreeChartTester extends junit.framework.TestCase {
  
  public JFreeChartTester(java.lang.String testName) {
    super(testName);
  }
  
  public static void main(java.lang.String[] args) {
    junit.textui.TestRunner.run(suite());
  }
  
  public static junit.framework.Test suite() {
    junit.framework.TestSuite suite = new junit.framework.TestSuite(JFreeChartTester.class);
    return suite;
  }
  
  
  public void testFourDataSetsSingleGraph() throws java.io.IOException {
    double[] dAryX = new double[] {0, 1, 2, 3};
    double[] dAryY = new double[] {4, 6, 9, 15};
    
    double[] dAryX2 = new double[] {-20, -12, 2, 6};
    double[] dAryY2 = new double[] {13, 56, 10, -8};
    
    double[] dAryX3 = new double[] {-15, -8, -3};
    double[] dAryY3 = new double[] {-10, -8, 5};
    
    double[] dAryX4 = new double[] {-21, -18, -11};
    double[] dAryY4 = new double[] {1, -5, -15};
    
    double[] dAryX5 = new double[] {-22, -19, -12, -6, 1};
    double[] dAryY5 = new double[] {1, -5, -15, -20, -15.5};
    

    /**
     * Plot with unequal axes
     */
    SimpleXYChart simpleXYUnequal = new SimpleXYChart();
    simpleXYUnequal.plot(dAryX, dAryY, java.awt.Color.MAGENTA, SimpleXYChart.DIAMOND, "Series A");
    // simpleXYUnequal.clearPlot();
    simpleXYUnequal.plot(dAryX2, dAryY2, java.awt.Color.GREEN, SimpleXYChart.TRIANGLE_UP, "Series B");
    simpleXYUnequal.plot(dAryX3, dAryY3);
    simpleXYUnequal.plot(dAryX4, dAryY4);
    simpleXYUnequal.plot(dAryX5, dAryY5, java.awt.Color.CYAN, "Plain Series");
    
    simpleXYUnequal.setTitle("Unequal Axes");
    simpleXYUnequal.setXLabel("X");
    simpleXYUnequal.setYLabel("Y");
    simpleXYUnequal.display();
    simpleXYUnequal.grid(true);
    simpleXYUnequal.axis(true);
    simpleXYUnequal.legend(true);
    
    XYPlot plot = simpleXYUnequal.getChart().getXYPlot();
//    double d1 = plot.getDomainAxis().getRange().getLength();
//    double d2 = plot.getRangeAxis().getRange().getLength();    
    
    XYPlot eqPlot = simpleXYUnequal.getChart().getXYPlot();
    eqPlot.useEqualAxes(false);
    
    
    /**
     * Plot with equal axes
     */
    SimpleXYChart simpleXYEqual = new SimpleXYChart();
    simpleXYEqual.plot(dAryX, dAryY, java.awt.Color.MAGENTA, SimpleXYChart.DIAMOND, "Series A");
    // simpleXYEqual.clearPlot();
    simpleXYEqual.plot(dAryX2, dAryY2, java.awt.Color.GREEN, SimpleXYChart.TRIANGLE_UP, "Series B");
    simpleXYEqual.plot(dAryX3, dAryY3);
    simpleXYEqual.plot(dAryX4, dAryY4);
    simpleXYEqual.plot(dAryX5, dAryY5, java.awt.Color.CYAN, "Plain Series");
    
    simpleXYEqual.setTitle("Equal Axes");
    simpleXYEqual.setXLabel("X");
    simpleXYEqual.setYLabel("Y");
    simpleXYEqual.display();
    simpleXYEqual.grid(true);
    simpleXYEqual.axis(true);
    simpleXYEqual.legend(true);
    
    plot = simpleXYEqual.getChart().getXYPlot();
//    double d1 = plot.getDomainAxis().getRange().getLength();
//    double d2 = plot.getRangeAxis().getRange().getLength();    
    
    eqPlot = simpleXYEqual.getChart().getXYPlot();
    eqPlot.useEqualAxes(true);
    
    
//    Object lock = new Object();
//    synchronized (lock) {
//      try {
//        lock.wait();
//      } catch (InterruptedException interruption) {
//      }
//    }
  }
   
  
  
  public void testBarCharts() {
    CategoryDataset dataset = createCategoryDataset();
    
    JFreeChart chart = ChartFactory.createBarChart("Bar Chart Demo", "Category", "Value", dataset, PlotOrientation.VERTICAL, true, true, false);
    // JFreeChart chart = ChartFactory.createBarChart("Bar Chart Demo", "Category", "Value", null, PlotOrientation.VERTICAL, true, true, false);
    
//    // add the chart to a panel ...
//    ChartPanel chartPanel = new ChartPanel(chart);
//    chartPanel.setPreferredSize(new java.awt.Dimension(500, 270));
    
    /**
     * Create an instance of SBExample1 and pack() the frame.
     */
    SimpleFrame frame = new SimpleFrame(chart);
    //frame.pack();
    /**
     * Since the current version of SGT Beans doesn't directly support
     * resizing disable resizing and make the frame visible.
     */
    // frame.setResizable(false);
    frame.setVisible(true);
    
    frame.setTitle(chart.getTitle().getText());
  }
  
  private CategoryDataset createCategoryDataset() {
    // row keys ...
    String series1 = "First";
    String series2 = "Second";
    String series3 = "Third";
    
    // column keys ...
    String category1 = "Category 1";
    String category2 = "Category 2";
    String category3 = "Category 3";
    String category4 = "Category 4";
    String category5 = "Category 5";
    
    // create the dataset ...
    DefaultCategoryDataset dataset = new DefaultCategoryDataset();
    
    dataset.addValue(1.0, series1, category1);
    dataset.addValue(4.0, series1, category2);
    dataset.addValue(-3.0, series1, category3);
    dataset.addValue(5.0, series1, category4);
    dataset.addValue(5.0, series1, category5);
    
    dataset.addValue(5.0, series2, category1);
    dataset.addValue(7.0, series2, category2);
    dataset.addValue(6.0, series2, category3);
    dataset.addValue(8.0, series2, category4);
    dataset.addValue(4.0, series2, category5);
    
    dataset.addValue(4.0, series3, category1);
    dataset.addValue(3.0, series3, category2);
    dataset.addValue(2.0, series3, category3);
    dataset.addValue(3.0, series3, category4);
    dataset.addValue(6.0, series3, category5);
    
    return dataset;
  }
  
  public void testSimpleBarChart1() {
    double[] dAryValues = {5, -1, -3, 2, 6};
    String[] strAryCategories = {"0", "12.1", "24.2", "36.3", "48.4"};
    String strSeriesName = "Series Test";
    
    SimpleBarChart chart = new SimpleBarChart(dAryValues, strAryCategories, strSeriesName);
    chart.display();
    chart.setTitle("Simple Bar Chart 1");
    chart.setCategoryLabel("Time [min]");
    chart.setValuesLabel("Force [N]");
    
    Object lock = new Object();
    synchronized (lock) {
      try {
        lock.wait();
      } catch (InterruptedException interruption) {
      }
    }    
  }
}